#!/bin/bash
#
# Syntaxe:
#   copie-preconf [-f fichier-identifiant] [-y] site-cible.cnrs.fr
#
# Description:
#   Installe un site avec le kit de préconfiguration DR15
#
#
#   Par défaut, le script demande de coller le contenu du mail
#   "Vos identifiants" reçu à la création du site cible et en
#   extrait les informations permettant de d'accéder au site
#   cible en SFTP et MySQL. Il demande confirmation à
#   l'utilisateur que ces identifiants sont corrects puis
#   les insèrez dans une copie temporaire de copie-preconf.php.
#
#   Ensuite, il copie les fichiers copie-preconf.{tar,sql,php} par
#   SFTP dans les répertoires appropriés du site cible.
#
#   Enfin, il effectue l'installation en exécutant le script
#   copie-preconf.php via une commande wget.
#
#   Options :
#   -f fichier-identifiants
#       Utilise fichier-identifiants pour trouver les identifiants
#       du site. Ce fichier contient un copier/coller du mail reçu
#      à la création du site
#
#   -y Ne demande pas confirmation à l'utilisateur de la validité
#      des identifants.
#
#  Prérequis :
#  - disposer de la sauvegarde des fichiers du site de référence
#     dans une archive nommée copie-preconf.tar
#  - disposer d'une sauvegarde de la base de données du site de
#    référence dans un fichier nommé copie-preconf.sql
#  - disposer du script copie-preconf.php

#
# Auteur:
#   Roland Dirlewanger, CNRS, octobre 2021.
#

#
# Les paramètres
#
SOURCE_FILES=copie-preconf.tar
SOURCE_DATABASE=copie-preconf.sql
INSTALLER=copie-preconf.php

# Traitement des arguments
#
usage() {
    cat <<"EOT" 1>&2
Usage: copie-preconf [-f fichier-identifiant] [-y] site-cible.cnrs.fr

Options :
    -f fichier-identifiants
       Utilise fichier-identifiants pour trouver les identifiants
       du site. Ce fichier contient un copier/coller du mail reçu
       à la création du site

    -y Ne demande pas confirmation à l'utilisateur de la validité
       des identifants.
EOT
    exit 1
}

CREDENTIALS=
YESMODE=0
while getopts "yf:" opt; do
    case "$opt" in
	f)
	    CREDENTIALS=$OPTARG
	    ;;

	y)
	    YESMODE=1
	    ;;

	*)
	    usage
    esac
done
shift `expr $OPTIND - 1`

if [ -z "$1" ]; then
    usage
fi
TARGET_NAME=$1

# Récupère l'adresse IP du client
IP_ADDRESS=$(wget -q --no-check-certificate -O - http://preconf.dr15.cnrs.fr/adresse-ip.php)
if [ -z "$IP_ADDRESS" ]; then
    echo "copie-preconf.sh: impossible de déterminer l'adresse IP de votre machine" 1>&2
    exit 1
fi
	     
# Fabrique un fichier temporaire et programme sa suppression à la
# fin du script
#
TMP=`mktemp /tmp/preconf-XXXXXXXXXXX`
trap "rm -rf $TMP" 0 1 2 3 15

# Récupère les informations de connexions à la base de données
# et les identifants SFTP
#
if [ -n "$CREDENTIALS" ]; then
    # A partir du fichier indiqué
    cp "$CREDENTIALS" $TMP || exit 1
else
    # A partir du terminal
    echo ">>> Coller ici le contenu du mail \"Vos identifiants\" reçu"
    echo ">>> à la création du site et terminez par un CTRL-D seul sur"
    echo ">>> une ligne."
    echo ">>> ---------------------------------------------------------"
    echo
    cat > $TMP
    echo
    echo ">>> ---------------------------------------------------------"
fi

# Extrait les informations utiles
#
SFTP_HOST=$(sed -n '/SFTP/,/^IP du serveur Web/s/IP.* //p' $TMP)
SFTP_PORT=$(sed -n '/SFTP/,/^Port/s/Port.* //p' $TMP)
SFTP_USER=$(sed -n '/SFTP/,/^Identifiant/s/Identifiant.* //p' $TMP)
SFTP_PASS=$(sed -n '/SFTP/,/^Mot de passe/s/Mot de passe.* //p' $TMP)

DATABASE_HOST=$(sed -n '/MYSQL/,/^Host du serveur/s/Host du serveur.* //p' $TMP)
DATABASE_NAME=$(sed -n '/MYSQL/,/^Base/s/Base.* //p' $TMP)
DATABASE_USER=$(sed -n '/MYSQL/,/^Identifiant/s/Identifiant.* //p' $TMP)
DATABASE_PASS=$(sed -n '/MYSQL/,/^Mot de passe/s/Mot de passe.* //p' $TMP)

# Confirme les identifiants
#
if [ $YESMODE = 0 ]; then
    echo "Identifiants pour le site $TARGET_NAME"
    echo
    echo "IP du serveur SFTP:   $SFTP_HOST"
    echo "Port SFTP:            $SFTP_PORT"
    echo "Identifiant SFTP:     $SFTP_USER"
    echo "Mot de passe SFTP:    $SFTP_PASS"

    echo

    echo "Nom du serveur MySQL: $DATABASE_HOST"
    echo "Base MySQL:           $DATABASE_NAME"
    echo "Identifiant MySQL:    $DATABASE_USER"
    echo "Mot de passe MySQL:   $DATABASE_PASS"

    echo

    read -p "Les identifiants ci-dessus sont-ils corrects [O/n] ? "
    case "$REPLY" in
	'' | [oOyY]*)
	    ;;
	*)
	    echo 1>&2
	    echo "Abandon !" 1>&2
	    exit 1
	    ;;
    esac
fi

# Patche le fichier copie-preconf.php
#
cp $INSTALLER $TMP

sed -i "s/^define.*TARGET_NAME.*/define(\"TARGET_NAME\", \"$TARGET_NAME\");/" $TMP

sed -i "s/^define.*AUTHORIZED_NETWORK.*/define(\"AUTHORIZED_NETWORK\", \"$IP_ADDRESS\");/" $TMP
sed -i "s/^define.*AUTHORIZED_MASK.*/define(\"AUTHORIZED_MASK\", 0xffffffff);/" $TMP

sed -i "s/^define.*DATABASE_HOST.*/define(\"DATABASE_HOST\", \"$DATABASE_HOST\");/" $TMP
sed -i "s/^define.*DATABASE_NAME.*/define(\"DATABASE_NAME\", \"$DATABASE_NAME\");/" $TMP
sed -i "s/^define.*DATABASE_USER.*/define(\"DATABASE_USER\", \"$DATABASE_USER\");/" $TMP
sed -i "s/^define.*DATABASE_PASS.*/define(\"DATABASE_PASS\", \"$DATABASE_PASS\");/" $TMP

# Copie les fichiers sur le site
#
sshpass -p $SFTP_PASS sftp \
     -o Port=$SFTP_PORT -o GSSAPIAuthentication=no \
     -o StrictHostKeyChecking=no -o PubkeyAuthentication=no \
     $SFTP_USER@$SFTP_HOST <<EOT
cd tmp
put copie-preconf.tar
put copie-preconf.sql
cd ../$TARGET_NAME/www
put $TMP $INSTALLER
quit
EOT
     

# Exécute l'installation du kit sur le site cible
#
wget -q -O - --no-check-certificate http://$TARGET_NAME/$INSTALLER

